"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const apputils_1 = require("@jupyterlab/apputils");
const console_1 = require("@jupyterlab/console");
const transient_1 = require("./transient");
const properties_1 = require("@phosphor/properties");
/**
 * The console widget tracker provider.
 */
exports.transient = {
    id: 'vatlab/jupyterlab-extension:transient',
    requires: [console_1.IConsoleTracker],
    optional: [apputils_1.ICommandPalette],
    activate: activateTransient,
    autoStart: true
};
exports.default = exports.transient;
function activateTransient(app, tracker, palette) {
    const { shell } = app;
    tracker.widgetAdded.connect((sender, panel) => {
        const console = panel.console;
        const handler = new transient_1.TransientHandler({
            session: console.session,
            parent: console
        });
        Private.transientHandlerProperty.set(console, handler);
        console.disposed.connect(() => {
            handler.dispose();
        });
    });
    const { commands } = app;
    const category = 'Console';
    const toggleShowTransientMessage = 'console:toggle-show-transient-message';
    // Get the current widget and activate unless the args specify otherwise.
    function getCurrent(args) {
        let widget = tracker.currentWidget;
        let activate = args['activate'] !== false;
        if (activate && widget) {
            shell.activateById(widget.id);
        }
        return widget;
    }
    commands.addCommand(toggleShowTransientMessage, {
        label: args => 'Show Transient Messages',
        execute: args => {
            let current = getCurrent(args);
            if (!current) {
                return;
            }
            const handler = Private.transientHandlerProperty.get(current.console);
            handler.enabled = !handler.enabled;
        },
        isToggled: () => tracker.currentWidget !== null &&
            Private.transientHandlerProperty.get(tracker.currentWidget.console).enabled,
        isEnabled: () => tracker.currentWidget !== null &&
            tracker.currentWidget === shell.currentWidget
    });
    if (palette) {
        palette.addItem({
            command: toggleShowTransientMessage,
            category,
            args: { isPalette: true }
        });
    }
    app.contextMenu.addItem({
        command: toggleShowTransientMessage,
        selector: '.jp-CodeConsole'
    });
}
/*
 * A namespace for private data.
 */
var Private;
(function (Private) {
    /**
     * An attached property for a console's transient handler.
     */
    Private.transientHandlerProperty = new properties_1.AttachedProperty({
        name: 'transientHandler',
        create: () => undefined
    });
})(Private || (Private = {}));
